# coding: utf-8

from .analyze import CZSC
from .factors import CzscFactors
from .utils.ta import SMA, EMA, MACD, KDJ

__version__ = "0.6.8"
__author__ = "zengbin93"
__email__ = "zeng_bin8888@163.com"

def get_s_names():
    """获取所有信号和因子的名称"""
    assert __version__ == '0.6.8'
    s_name = [
        '1分钟_倒1方向',
        '1分钟_倒1长度',
        '1分钟_倒1涨跌幅',
        '1分钟_倒1拟合优度',
        '1分钟_倒1近五笔最高点',
        '1分钟_倒1近五笔最低点',
        '1分钟_倒1近七笔最高点',
        '1分钟_倒1近七笔最低点',
        '1分钟_倒1近九笔最高点',
        '1分钟_倒1近九笔最低点',
        '1分钟_倒1近十一笔最高点',
        '1分钟_倒1近十一笔最低点',
        '1分钟_倒1近十三笔最高点',
        '1分钟_倒1近十三笔最低点',
        '1分钟_倒1近十五笔最高点',
        '1分钟_倒1近十五笔最低点',
        '1分钟_倒2方向',
        '1分钟_倒2长度',
        '1分钟_倒2涨跌幅',
        '1分钟_倒2拟合优度',
        '1分钟_倒3方向',
        '1分钟_倒3长度',
        '1分钟_倒3涨跌幅',
        '1分钟_倒3拟合优度',
        '1分钟_倒4方向',
        '1分钟_倒4长度',
        '1分钟_倒4涨跌幅',
        '1分钟_倒4拟合优度',
        '1分钟_倒5方向',
        '1分钟_倒5长度',
        '1分钟_倒5涨跌幅',
        '1分钟_倒5拟合优度',
        '1分钟_倒1五笔',
        '1分钟_倒2五笔',
        '1分钟_倒3五笔',
        '1分钟_倒4五笔',
        '1分钟_倒5五笔',
        '1分钟_倒1七笔',
        '1分钟_倒2七笔',
        '1分钟_倒3七笔',
        '1分钟_倒4七笔',
        '1分钟_倒5七笔',
        '1分钟_倒1九笔',
        '1分钟_倒2九笔',
        '1分钟_倒3九笔',
        '1分钟_倒4九笔',
        '1分钟_倒5九笔',
        '5分钟_倒1方向',
        '5分钟_倒1长度',
        '5分钟_倒1涨跌幅',
        '5分钟_倒1拟合优度',
        '5分钟_倒1近五笔最高点',
        '5分钟_倒1近五笔最低点',
        '5分钟_倒1近七笔最高点',
        '5分钟_倒1近七笔最低点',
        '5分钟_倒1近九笔最高点',
        '5分钟_倒1近九笔最低点',
        '5分钟_倒1近十一笔最高点',
        '5分钟_倒1近十一笔最低点',
        '5分钟_倒1近十三笔最高点',
        '5分钟_倒1近十三笔最低点',
        '5分钟_倒1近十五笔最高点',
        '5分钟_倒1近十五笔最低点',
        '5分钟_倒2方向',
        '5分钟_倒2长度',
        '5分钟_倒2涨跌幅',
        '5分钟_倒2拟合优度',
        '5分钟_倒3方向',
        '5分钟_倒3长度',
        '5分钟_倒3涨跌幅',
        '5分钟_倒3拟合优度',
        '5分钟_倒4方向',
        '5分钟_倒4长度',
        '5分钟_倒4涨跌幅',
        '5分钟_倒4拟合优度',
        '5分钟_倒5方向',
        '5分钟_倒5长度',
        '5分钟_倒5涨跌幅',
        '5分钟_倒5拟合优度',
        '5分钟_倒1五笔',
        '5分钟_倒2五笔',
        '5分钟_倒3五笔',
        '5分钟_倒4五笔',
        '5分钟_倒5五笔',
        '5分钟_倒1七笔',
        '5分钟_倒2七笔',
        '5分钟_倒3七笔',
        '5分钟_倒4七笔',
        '5分钟_倒5七笔',
        '5分钟_倒1九笔',
        '5分钟_倒2九笔',
        '5分钟_倒3九笔',
        '5分钟_倒4九笔',
        '5分钟_倒5九笔',
        '15分钟_倒1方向',
        '15分钟_倒1长度',
        '15分钟_倒1涨跌幅',
        '15分钟_倒1拟合优度',
        '15分钟_倒1近五笔最高点',
        '15分钟_倒1近五笔最低点',
        '15分钟_倒1近七笔最高点',
        '15分钟_倒1近七笔最低点',
        '15分钟_倒1近九笔最高点',
        '15分钟_倒1近九笔最低点',
        '15分钟_倒1近十一笔最高点',
        '15分钟_倒1近十一笔最低点',
        '15分钟_倒1近十三笔最高点',
        '15分钟_倒1近十三笔最低点',
        '15分钟_倒1近十五笔最高点',
        '15分钟_倒1近十五笔最低点',
        '15分钟_倒2方向',
        '15分钟_倒2长度',
        '15分钟_倒2涨跌幅',
        '15分钟_倒2拟合优度',
        '15分钟_倒3方向',
        '15分钟_倒3长度',
        '15分钟_倒3涨跌幅',
        '15分钟_倒3拟合优度',
        '15分钟_倒4方向',
        '15分钟_倒4长度',
        '15分钟_倒4涨跌幅',
        '15分钟_倒4拟合优度',
        '15分钟_倒5方向',
        '15分钟_倒5长度',
        '15分钟_倒5涨跌幅',
        '15分钟_倒5拟合优度',
        '15分钟_倒1五笔',
        '15分钟_倒2五笔',
        '15分钟_倒3五笔',
        '15分钟_倒4五笔',
        '15分钟_倒5五笔',
        '15分钟_倒1七笔',
        '15分钟_倒2七笔',
        '15分钟_倒3七笔',
        '15分钟_倒4七笔',
        '15分钟_倒5七笔',
        '15分钟_倒1九笔',
        '15分钟_倒2九笔',
        '15分钟_倒3九笔',
        '15分钟_倒4九笔',
        '15分钟_倒5九笔',
        '30分钟_倒1方向',
        '30分钟_倒1长度',
        '30分钟_倒1涨跌幅',
        '30分钟_倒1拟合优度',
        '30分钟_倒1近五笔最高点',
        '30分钟_倒1近五笔最低点',
        '30分钟_倒1近七笔最高点',
        '30分钟_倒1近七笔最低点',
        '30分钟_倒1近九笔最高点',
        '30分钟_倒1近九笔最低点',
        '30分钟_倒1近十一笔最高点',
        '30分钟_倒1近十一笔最低点',
        '30分钟_倒1近十三笔最高点',
        '30分钟_倒1近十三笔最低点',
        '30分钟_倒1近十五笔最高点',
        '30分钟_倒1近十五笔最低点',
        '30分钟_倒2方向',
        '30分钟_倒2长度',
        '30分钟_倒2涨跌幅',
        '30分钟_倒2拟合优度',
        '30分钟_倒3方向',
        '30分钟_倒3长度',
        '30分钟_倒3涨跌幅',
        '30分钟_倒3拟合优度',
        '30分钟_倒4方向',
        '30分钟_倒4长度',
        '30分钟_倒4涨跌幅',
        '30分钟_倒4拟合优度',
        '30分钟_倒5方向',
        '30分钟_倒5长度',
        '30分钟_倒5涨跌幅',
        '30分钟_倒5拟合优度',
        '30分钟_倒1五笔',
        '30分钟_倒2五笔',
        '30分钟_倒3五笔',
        '30分钟_倒4五笔',
        '30分钟_倒5五笔',
        '30分钟_倒1七笔',
        '30分钟_倒2七笔',
        '30分钟_倒3七笔',
        '30分钟_倒4七笔',
        '30分钟_倒5七笔',
        '30分钟_倒1九笔',
        '30分钟_倒2九笔',
        '30分钟_倒3九笔',
        '30分钟_倒4九笔',
        '30分钟_倒5九笔',
        '60分钟_倒1方向',
        '60分钟_倒1长度',
        '60分钟_倒1涨跌幅',
        '60分钟_倒1拟合优度',
        '60分钟_倒1近五笔最高点',
        '60分钟_倒1近五笔最低点',
        '60分钟_倒1近七笔最高点',
        '60分钟_倒1近七笔最低点',
        '60分钟_倒1近九笔最高点',
        '60分钟_倒1近九笔最低点',
        '60分钟_倒1近十一笔最高点',
        '60分钟_倒1近十一笔最低点',
        '60分钟_倒1近十三笔最高点',
        '60分钟_倒1近十三笔最低点',
        '60分钟_倒1近十五笔最高点',
        '60分钟_倒1近十五笔最低点',
        '60分钟_倒2方向',
        '60分钟_倒2长度',
        '60分钟_倒2涨跌幅',
        '60分钟_倒2拟合优度',
        '60分钟_倒3方向',
        '60分钟_倒3长度',
        '60分钟_倒3涨跌幅',
        '60分钟_倒3拟合优度',
        '60分钟_倒4方向',
        '60分钟_倒4长度',
        '60分钟_倒4涨跌幅',
        '60分钟_倒4拟合优度',
        '60分钟_倒5方向',
        '60分钟_倒5长度',
        '60分钟_倒5涨跌幅',
        '60分钟_倒5拟合优度',
        '60分钟_倒1五笔',
        '60分钟_倒2五笔',
        '60分钟_倒3五笔',
        '60分钟_倒4五笔',
        '60分钟_倒5五笔',
        '60分钟_倒1七笔',
        '60分钟_倒2七笔',
        '60分钟_倒3七笔',
        '60分钟_倒4七笔',
        '60分钟_倒5七笔',
        '60分钟_倒1九笔',
        '60分钟_倒2九笔',
        '60分钟_倒3九笔',
        '60分钟_倒4九笔',
        '60分钟_倒5九笔',
        '日线_倒1方向',
        '日线_倒1长度',
        '日线_倒1涨跌幅',
        '日线_倒1拟合优度',
        '日线_倒1近五笔最高点',
        '日线_倒1近五笔最低点',
        '日线_倒1近七笔最高点',
        '日线_倒1近七笔最低点',
        '日线_倒1近九笔最高点',
        '日线_倒1近九笔最低点',
        '日线_倒1近十一笔最高点',
        '日线_倒1近十一笔最低点',
        '日线_倒1近十三笔最高点',
        '日线_倒1近十三笔最低点',
        '日线_倒1近十五笔最高点',
        '日线_倒1近十五笔最低点',
        '日线_倒2方向',
        '日线_倒2长度',
        '日线_倒2涨跌幅',
        '日线_倒2拟合优度',
        '日线_倒3方向',
        '日线_倒3长度',
        '日线_倒3涨跌幅',
        '日线_倒3拟合优度',
        '日线_倒4方向',
        '日线_倒4长度',
        '日线_倒4涨跌幅',
        '日线_倒4拟合优度',
        '日线_倒5方向',
        '日线_倒5长度',
        '日线_倒5涨跌幅',
        '日线_倒5拟合优度',
        '日线_倒1五笔',
        '日线_倒2五笔',
        '日线_倒3五笔',
        '日线_倒4五笔',
        '日线_倒5五笔',
        '日线_倒1七笔',
        '日线_倒2七笔',
        '日线_倒3七笔',
        '日线_倒4七笔',
        '日线_倒5七笔',
        '日线_倒1九笔',
        '日线_倒2九笔',
        '日线_倒3九笔',
        '日线_倒4九笔',
        '日线_倒5九笔',
        '日线笔因子',
        '日线笔结束',
        '60分钟笔因子',
        '60分钟笔结束',
        '30分钟笔因子',
        '30分钟笔结束',
        '15分钟笔因子',
        '15分钟笔结束',
        '5分钟笔结束'
    ]
    return s_name

